#include <algorithm>
#include <iostream>
#include <iomanip>
#include <numeric>
#include <cassert>
#include <vector>
#include <cmath>

typedef long long llong;
const int MAXN = 100 + 10;
const llong INF = 1e18;
const int INTINF = 1e9;

int n;
long double r;
long double a[MAXN];
struct Point
{
    long double x, y;
    Point(){}
    Point(long double _x, long double _y)
    {
        x = _x;
        y = _y;
    }
};

struct Circle
{
    Point center;
    long double radius;
} c[MAXN];

struct Line
{
    long double a, b;
};

Line getLine(const Circle &a, const Circle &b)
{
    Line result;
    result.a = 2.0l*b.center.x - 2.0l*a.center.x;
    result.b = a.center.x * a.center.x + a.center.y * a.center.y + b.radius * b.radius - b.center.x * b.center.x - b.center.y * b.center.y - a.radius * a.radius;
    result.a /= (2.0l*a.center.y - 2.0l*b.center.y);
    result.b /= (2.0l*a.center.y - 2.0l*b.center.y);
    return result;
}

Point getIntersections(const Circle &c, Line l)
{
    long double aCoef = l.a * l.a + 1.0l;
    long double bCoef = 2.0l * l.a * l.b - 2.0l*c.center.x - 2.0l*l.a*c.center.y;
    long double cCoef = c.center.x * c.center.x + c.center.y * c.center.y - 2.0l * c.center.y * l.b + l.b*l.b - c.radius * c.radius;
    long double d = bCoef * bCoef - 4.0l * aCoef * cCoef;
    if (d < 0) d = 0;

    long double p1 = (-bCoef - sqrtl(d)) / (2.0l*aCoef);
    long double p2 = (-bCoef + sqrtl(d)) / (2.0l*aCoef);
    Point a = {p1, l.a * p1 + l.b};
    Point b = {p2, l.a * p2 + l.b};
    if (a.y > b.y) return a;
    else return b;
}

long double getDist(const Point &a, const Point &b)
{
    return sqrtl((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

Point getIntersection(Point A, Point B)
{
    if (fabs(A.y - B.y) < 1e-9)
    {
        Point up = {(A.x + B.x) / 2.0, A.y};
        long double deltaY = sqrtl(4.0 * r * r - getDist(A, up) * getDist(A, up));
        up.y += deltaY;
        return up;
    }

    Circle a = {A, 2.0 * r};
    Circle b = {B, 2.0 * r};
    return getIntersections(a, getLine(a, b));
}

std::vector <Point> getNEW(std::vector <Point> curr)
{
    std::vector <Point> newP;
    for (int i = 0 ; i + 1 < curr.size() ; ++i)
    {
        newP.push_back(getIntersection(curr[i], curr[i + 1]));
    }

    return newP;
}

std::vector <Point> curr;
void solve()
{
    std::sort(a + 1, a + 1 + n);
    for (int i = 1 ; i <= n ; ++i)
    {
        curr.push_back({a[i], r});
    }

    for (int i = 1 ; i < n ; ++i)
    {
        curr = getNEW(curr);
    }

    std::cout << std::fixed << std::setprecision(10) << curr[0].x << ' ' << curr[0].y + r << '\n';
}

void input()
{
    std::cin >> n >> r;
    for (int i = 1 ; i <= n ; ++i)
    {
        std::cin >> a[i];
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIOI();
    input();
    solve();

    return 0;
}