#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>

typedef long long llong;
const int MAXN = 200000 + 10;
const llong INF = 1e18;
const int INTINF = 1e9;

int a[MAXN];
char ans[MAXN];

struct DSU
{
    int par[MAXN];
    int dep[MAXN];
    llong sum[MAXN];
    std::vector <int> active[MAXN];

    void build(int n)
    {
        for (int i = 1 ; i <= n ; ++i)
        {
            par[i] = i;
            dep[i] = 1;
            ans[i] = '1';
            sum[i] = a[i];
            active[i].push_back(i);
        }
    }

    int find(int u)
    {
        if (par[u] == u) return u;
        return par[u] = find(par[u]);
    }

    void connect(int u, int v)
    {
        u = find(u);
        v = find(v);

        if (u == v)
        {
            return;
        }

        if (dep[u] > dep[v])
        {
            std::swap(u, v);
        }

        if (dep[u] == dep[v])
        {
            dep[v]++;
        }

        par[u] = v;
        sum[v] += sum[u];
        for (const int &i : active[u])
        {
            active[v].push_back(i);
        }
    }

    bool areConnected(int u, int v)
    {
        return find(u) == find(v);
    }

    llong getSum(int u)
    {
        return sum[find(u)];
    }

    void clear(int u)
    {
        u = find(u);
        for (const int &i : active[u])
        {
            ans[i] = '0';
        }
    }
};

int n, m;
int perm[MAXN];
bool smaller[MAXN];
std::vector <int> g[MAXN];
DSU dsu;

void solve()
{
    std::iota(perm + 1, perm + 1 + n, 1);
    std::sort(perm + 1, perm + 1 + n, [&](int x, int y)
    {
        return a[x] < a[y] || (a[x] == a[y] && x < y);
    });

    dsu.build(n);
    for (int i = 1 ; i <= n ; ++i)
    {
        int u = perm[i];
        for (const int &v : g[u])
        {
            if (smaller[v] && !dsu.areConnected(u, v))
            {
                if (dsu.getSum(v) < a[u])
                {
                    dsu.clear(v);
                }

                dsu.connect(u, v);
            }
        }

        smaller[u] = true;
    }

    ans[n + 1] = '\0';
    std::cout << ans + 1 << '\n';
}

void input()
{
    std::cin >> n >> m;
    for (int i = 1 ; i <= n ; ++i)
    {
        std::cin >> a[i];
    }
 
    for (int i = 1 ; i <= m ; ++i)
    {
        int u, v;
        std::cin >> u >> v;
        g[u].push_back(v);
        g[v].push_back(u);
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIOI();
    input();
    solve();

    return 0;
}