#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>

typedef long long llong;
const int MAXN = 1000 + 10;
const llong INF = 1e18;
const int INTINF = 1e9;

int n;
int par[MAXN];
int dep[MAXN];
int edgeIdx[MAXN];
std::vector <std::pair <int,int>> g[MAXN];

void initDFS(int u)
{
    for (int i = 0 ; i < g[u].size() ; ++i)
    {
        if (g[u][i].first == par[u])
        {
            continue;
        }

        edgeIdx[g[u][i].first] = i;
        par[g[u][i].first] = u;
        initDFS(g[u][i].first);
    }
}

void dfs(int u)
{
    for (const auto &[v, d] : g[u])
    {
        if (v == par[u])
        {
            continue;
        }

        dep[v] = dep[u] + d;
        dfs(v);
    }
}

void climb(int node)
{
    if (node == 1)
    {
        return;
    }
    
    g[par[node]][edgeIdx[node]].second = 0;
    climb(par[node]);
}

void solve()
{
    llong irma = 0;
    llong alex = 0;
    bool turn = false;

    initDFS(1);
    while (true)
    {
        dfs(1);
        int max = 1;

        for (int i = 2 ; i <= n ; ++i)
        {
            if (dep[i] > dep[max])
            {
                max = i;
            }
        }

        if (max == 1)
        {
            break;
        }

        if (turn)
        {
            alex += dep[max];
        } else
        {
            irma += dep[max];
        }

        turn = !turn;
        climb(max);
    }

    if (irma > alex)
    {
        std::cout << "Irma " << irma << '\n';
    } else
    {
        std::cout << "Draw\n";
    }
}

void input()
{
    std::cin >> n;
    for (int i = 1 ; i < n ; ++i)
    {
        int u, v, w;
        std::cin >> u >> v >> w;
        g[u].push_back({v, w});
        g[v].push_back({u, w});
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIOI();
    input();
    solve();

    return 0;
}