#include <algorithm>
#include <iostream>
#include <iomanip>
#include <numeric>
#include <cassert>
#include <cstring>
#include <vector>
#include <cmath>

typedef long long llong;
const int MAXN = 50 + 10;
const int MOD = 1000003;
const llong INF = 1e18;
const int INTINF = 1e9;

int n, k, p;
struct Pattern
{
    char s[MAXN];
    Pattern()
    {
        for (int i = 0 ; i < p ; ++i)
        {
            s[i] = '?';
        }
    }

    int getCount()
    {
        int res = 1;
        for (int i = 0 ; i < p ; ++i)
        {
            if (s[i] == '?')
            {
                res *= 26;
                res %= MOD;
            }
        }

        return res;
    }
};

Pattern pat[MAXN];
bool canMerge(Pattern a, Pattern b)
{
    for (int i = 0 ; i < p ; ++i)
    {
        if (a.s[i] != b.s[i] && a.s[i] != '?' && b.s[i] != '?')
        {
            return false;
        }
    }

    return true;
}

Pattern merge(Pattern a, Pattern b)
{
    Pattern res;
    for (int i = 0 ; i < p ; ++i)
    {
        if (a.s[i] == b.s[i])
        {
            res.s[i] = a.s[i];
            continue;
        }

        if (a.s[i] == '?') res.s[i] = b.s[i];
        else res.s[i] = a.s[i];
    }

    return res;
}

std::vector <Pattern> v;
int inclusion(int idx, int par, Pattern merged)
{
    if (idx == v.size())
    {
        if (!par) return merged.getCount();
        else return MOD - merged.getCount();
    }

    int ans = inclusion(idx + 1, par, merged);
    if (canMerge(merged, v[idx]))
    {
        ans += inclusion(idx + 1, par ^ 1, merge(merged, v[idx]));
        if (ans >= MOD) ans -= MOD;
    }

    return ans;
}

void solve()
{
    int ans = 0;
    for (int mask = 0 ; mask < (1 << n) ; ++mask)
    {
        if (__builtin_popcount(mask) != k)
        {
            continue;
        }

        Pattern curr;
        bool good = true;
        v.clear();

        for (int i = 1 ; i <= n ; ++i)
        {
            if (mask & (1 << i - 1))
            {
                good &= canMerge(curr, pat[i]);
                if (!good)
                {
                    break;
                }

                curr = merge(curr, pat[i]);
            } else
            {
                v.push_back(pat[i]);
            }
        }

        if (!good)
        {
            continue;
        }
        
        ans += inclusion(0, 0, curr);
        if (ans >= MOD) ans -= MOD;
    }

    std::cout << ans << '\n';
}

void input()
{
    std::cin >> n >> k;
    for (int i = 1 ; i <= n ; ++i)
    {
        std::cin >> pat[i].s;
        p = strlen(pat[i].s);
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIOI();
    input();
    solve();

    return 0;
}