#include <algorithm>
#include <iostream>
#include <iomanip>
#include <numeric>
#include <cassert>
#include <cstring>
#include <vector>
#include <cmath>

#define int long long
typedef long long llong;
const int MAXN = 1000000 + 10;
const llong INF = 2e12;
const int INTINF = 1e9;

int h, w, n;
struct SegmentTree
{
    struct Node
    {
        int lazy;
        llong max;
        llong l, r;
    
        Node()
        {
            max = lazy = 0;
            l = r = 0;
        }
    };

    std::vector <Node> tree;
    void update(int l, int r, int node, int queryL, int queryR, int val)
    {
        if (queryL <= l && r <= queryR)
        {
            tree[node].lazy = std::max(tree[node].lazy, val);
            tree[node].max = std::max(tree[node].max, tree[node].lazy);
            return;
        }

        int mid = (l + r) / 2;
        if (queryL <= mid)
        {
            if (tree[node].l == 0)
            {
                Node newNode;
                tree.push_back(newNode);
                tree[node].l = tree.size() - 1;
            }

            update(l, mid, tree[node].l, queryL, queryR, val);
        }
        
        if (mid + 1 <= queryR)
        {
            if (tree[node].r == 0)
            {
                Node newNode;
                tree.push_back(newNode);
                tree[node].r = tree.size() - 1;
            }

            update(mid + 1, r, tree[node].r, queryL, queryR, val);
        }

        tree[node].max = tree[node].lazy;
        tree[node].max = std::max(tree[node].max, tree[tree[node].l].max);
        tree[node].max = std::max(tree[node].max, tree[tree[node].r].max);
    }

    int query(int l, int r, int node, int queryL, int queryR, int lazy)
    {
        if (node == 0)
        {
            return 0;
        }

        lazy = std::max(lazy, tree[node].lazy);
        if (queryL <= l && r <= queryR)
        {
            return std::max(lazy, tree[node].max);
        }

        int res = 0;
        int mid = (l + r) / 2;
        if (queryL <= mid) res = std::max(res, query(l, mid, tree[node].l, queryL, queryR, lazy));
        if (mid + 1 <= queryR) res = std::max(res, query(mid + 1, r, tree[node].r, queryL, queryR, lazy));
        return res;
    }

    void build()
    {
        tree.resize(2);
    }

    void update(int l, int r, int val)
    {
        update(0, INF, 1, l, r, val);
    }

    int query(int l, int r)
    {
        return query(0, INF, 1, l, r, 0);
    }
};

SegmentTree tree;
struct Point
{
    llong x, y;
    int idx;

    friend bool operator < (const Point &a, const Point &b)
    {
        return (a.x < b.x) || (a.x == b.x && a.y < b.y);
    }
};

Point p[MAXN];
llong ans[MAXN];
void solve()
{
    h *= 2;
    w *= 2;
    tree.build();
    tree.update(0, 0, INF);
    std::sort(p + 1, p + 1 + n);

    for (int i = 1 ; i <= n ; ++i)
    {
        int l = 0, r = p[i].y, mid;
        while (l < r - 1)
        {
            mid = (l + r) / 2;
            if (tree.query(mid, p[i].y) >= p[i].x) l = mid;
            else r = mid;
        }

        ans[p[i].idx] = p[i].y - l;
        tree.update(l, p[i].y + (p[i].y - l), p[i].x + p[i].y - l);
    }
}

void print()
{
    for (int i = 1 ; i <= n ; ++i)
    {
        std::cout << ans[i] << '\n';
    }
}

void input()
{
    std::cin >> h >> w >> n;
    for (int i = 1 ; i <= n ; ++i)
    {
        double x, y;
        std::cin >> x >> y;
        x *= 2; y *= 2;
        p[i] = {round(x), round(y), i};
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

signed main()
{
    fastIOI();
    input();
    solve();
    print();

    return 0;
}